@@ -1,7 +1,7 @@
 from xpath2_functions import functions as xpath_fns
 
 
-def register_functions(etree, ns='kjw.pt/xpath2-functions', functions=None):
+def register_functions(etree, ns='http://kjw.pt/xpath2-functions', functions=None):
     """
     Usage::
 
